import sys
import os

from distutils.sysconfig import * # This is needed for eric3

from qt import QApplication, QTranslator, QTextCodec, QPixmap, QPoint, \
    QLabel, Qt, QFrame, QRect, QPainter, QFont, QMimeSourceFactory, \
    SIGNAL, SLOT, QVBox, qApp



def startEric(ericDir):

    import eric3             # Placed here so we can change the path

    """
    Main entry point into the application.
    """
    
    if ericDir == '':
        ericDir = '.'

##    print "sys.argv = ", sys.argv
##    print "ericDir = ", ericDir
    app = QApplication(sys.argv)
    
    # set the searchpath for icons
    eric3.initializeMimeSourceFactory(ericDir)

    # generate and show a splash window, if not suppressed
    if "--nosplash" in sys.argv:
        del sys.argv[sys.argv.index("--nosplash")]
        splash = eric3.NoneSplashScreen(ericDir)
    else:
        splash = eric3.SplashScreen(ericDir)

    # is there a set of filenames or options on the command line,
    # if so, pass them to the UI
    args = None
    if len(sys.argv) > 1:
        args = sys.argv[1:]
    
    # Set the applications string encoding
    try:
        sys.setappdefaultencoding(str(eric3.Preferences.getSystem("StringEncoding")))
    except:
        pass
    
    # get the Qt installation directory
    qtdir = eric3.Preferences.getQtDir()
    if qtdir is not None:
        if eric3.Preferences.getQt("ExportQtDir"):
            os.environ["QTDIR"] = qtdir
    
    # Load translation files and install them
    loaded = 0
    loc = eric3.Preferences.getUILanguage()
    if loc is not None:
        if loc == "System":
            loc = str(QTextCodec.locale())
        
        if loc != "C":
            # setup the searchpath for qt and qscintilla
            dirs = [ericDir, "."]
            if qtdir is not None:
                dirs.insert(-1, os.path.join(qtdir, "translations"))
                
            # 1) load translations for qt
            qtTrans, ok = eric3.loadTranslator(dirs, "qt_" + loc)
            if ok:
                app.installTranslator(qtTrans)
                
            # 2) load translations for qscintilla
            scintillaTrans, ok = eric3.loadTranslator(dirs, "qscintilla_" + loc)
            if ok:
                app.installTranslator(scintillaTrans)
                
            # 3) load translations for eric
            dirs = [".", ericDir]
            ericTrans, ok = eric3.loadTranslator(dirs, "eric3_" + loc)
            if ok:
                app.installTranslator(ericTrans)
            else:
                print "Please report to <eric-bugs@die-offenbachs.de>."
        else:
            loc = None
        
    splash.message(qApp.translate("eric3", "Importing packages..."))
    # We can only import these after creating the QApplication because they
    # make Qt calls that need the QApplication to exist.
    from UI.UserInterface import UserInterface

    splash.message(qApp.translate("eric3", "Generating Main Window..."))
    mw = UserInterface(loc, splash)
    app.setMainWidget(mw)
    app.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
    mw.show()

    splash.message(qApp.translate("eric3", "Loading files..."))
    mw.processArgs(args)
    
    if splash:
        del splash
        
    res = app.exec_loop()
    return 



def main(argv = None):
    if argv is None:
        argv = sys.argv

    #
    # A couple of notes here:
    # o We need to add eric3's path to sys.path
    # o We cannot use eric3's main entry since it calls sys.exit
    #

    site = get_python_lib()
    eric3Application = os.path.join(site, "eric3/eric3.py")
    ericDir = os.path.dirname(eric3Application)
    sys.path.insert(0, ericDir)         # Needed at first for debugger
    sys.argv.insert(0, eric3Application)

##    print "sys.path = ", sys.path
##    print "sys.path[0] = ", sys.path[0]
    startEric(ericDir)
    
    return None



if __name__ == "__main__":
    sys.exit(main() or 0)